themeMode property
DigiaThemeMode
get
themeMode
The theme currently used to render Campaign Canvas colors.
Implementation
static DigiaThemeMode get themeMode => DigiaInstance.instance.themeMode;
The theme currently used to render Campaign Canvas colors.
static DigiaThemeMode get themeMode => DigiaInstance.instance.themeMode;