onCampaignTriggered abstract method
Called when the CEP has evaluated a campaign and it is ready to render. Digia routes the payload to nudge or inline surfaces based on command.
Implementation
void onCampaignTriggered(InAppPayload payload);
Called when the CEP has evaluated a campaign and it is ready to render. Digia routes the payload to nudge or inline surfaces based on command.
void onCampaignTriggered(InAppPayload payload);