InlineTimerRule class final

Constructors

InlineTimerRule({double? cornerRadius, InlineCanvasMargin? margin, required InlineTimerState state, required String id, required CampaignCanvas? canvas})
const

Properties

canvas CampaignCanvas?
final
cornerRadius double?
final
hashCode int
The hash code for this object.
no setterinherited
id String
final
margin InlineCanvasMargin?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
state InlineTimerState
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited