ResolvedInlineTimerConfig class final

Constructors

ResolvedInlineTimerConfig({required String slotKey, required double designWidth, required double cornerRadius, required InlineCanvasMargin margin, required DateTime? startsAt, required DateTime deadline, required InlineTimerDeadlineSource deadlineSource, required int? urgentBelowSeconds, required Map<InlineTimerState, InlineTimerRule> rules, required ServerTimeClock clock})
const

Properties

clock ServerTimeClock
final
cornerRadius double
final
deadline DateTime
final
deadlineSource InlineTimerDeadlineSource
final
designWidth double
final
hashCode int
The hash code for this object.
no setterinherited
margin InlineCanvasMargin
final
now DateTime
no setter
remaining Duration
no setter
rules Map<InlineTimerState, InlineTimerRule>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
slotKey String
final
startsAt DateTime?
final
state InlineTimerState
no setter
urgentBelowSeconds int?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited