CarouselIndicatorConfig class

Page-indicator styling for an inline carousel.

Dart port of the Android CarouselIndicatorConfig data class. Colours are kept as hex strings exactly as delivered by the backend and parsed at render time.

Constructors

CarouselIndicatorConfig({bool showIndicator = true, double dotHeight = 8, double dotWidth = 8, double spacing = 12, String dotColor = '#CBD5E1', String activeDotColor = '#4945FF', String indicatorEffectType = 'slide'})
const

Properties

activeDotColor String
final
dotColor String
final
dotHeight double
final
dotWidth double
final
hashCode int
The hash code for this object.
no setterinherited
indicatorEffectType String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
showIndicator bool
final
spacing double
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

fromJson(Map<String, dynamic>? json) CarouselIndicatorConfig