CarouselItem class
A single image slide in an inline carousel campaign.
Dart port of the Android CarouselItem data class.
Constructors
- CarouselItem({required String imageUrl, String? deepLink, ImagePlaceholder? placeholder})
-
const
Properties
- deepLink → String?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- imageUrl → String
-
final
- placeholder → ImagePlaceholder?
-
Loading placeholder shown while imageUrl loads;
nullwhen the payload carries noplaceholder.final - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited