height property
Fixed image-frame height retained as a fallback for legacy payloads and older SDKs that do not understand aspectRatio.
Implementation
final int height;
Fixed image-frame height retained as a fallback for legacy payloads and older SDKs that do not understand aspectRatio.
final int height;