CountdownCardMargin class

Outer spacing between the countdown card and its slot bounds.

Constructors

CountdownCardMargin({double top = 0, double right = 0, double bottom = 0, double left = 0})
const
CountdownCardMargin.fromJson(Map<String, dynamic>? json)
factory

Properties

bottom double
final
hashCode int
The hash code for this object.
no setterinherited
left double
final
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
top double
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited