CountdownCardPadding class

Inner spacing between the countdown card's border and its content.

Constructors

CountdownCardPadding({double top = 13, double right = 14, double bottom = 12, double left = 14})
const
CountdownCardPadding.fromJson(Map<String, dynamic>? json)
factory

Properties

bottom double
final
hashCode int
The hash code for this object.
no setterinherited
left double
final
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
top double
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited