CountdownExpiredContent class

Content rendered after the countdown reaches zero.

Constructors

CountdownExpiredContent({required CountdownHeaderContent header, String? bodyImageUrl, ImagePlaceholder? bodyImagePlaceholder, required String bodyText, required String ctaText})
const

Properties

bodyImagePlaceholder ImagePlaceholder?
final
bodyImageUrl String?
final
bodyText String
final
ctaText String
final
hashCode int
The hash code for this object.
no setterinherited
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
resolve(VariableScope variables) CountdownExpiredContent?
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited