CountdownHeaderContent class

Title, subtitle, and optional leading image shared by both card states.

Constructors

CountdownHeaderContent({required String title, required String subtitle, String? imageUrl, ImagePlaceholder? imagePlaceholder})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
imagePlaceholder ImagePlaceholder?
final
imageUrl String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
subtitle String
final
title String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
resolve(VariableScope variables) CountdownHeaderContent?
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited