CampaignCanvasGradientPaint class final

Inheritance

Constructors

CampaignCanvasGradientPaint({CampaignCanvasGradientType gradientType = CampaignCanvasGradientType.linear, double angleDegrees = 180, double centerX = .5, double centerY = .5, double radius = .5, double startAngleDegrees = 0, double endAngleDegrees = 360, List<CampaignCanvasGradientStop> stops = const []})
const

Properties

angleDegrees double
final
centerX double
final
centerY double
final
endAngleDegrees double
final
gradientType CampaignCanvasGradientType
final
hashCode int
The hash code for this object.
no setterinherited
radius double
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
startAngleDegrees double
final
stops List<CampaignCanvasGradientStop>
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited