CampaignCanvasImage class final

Inheritance

Constructors

CampaignCanvasImage(CampaignCanvasBox box, {required String url, required BoxFit fit, ImagePlaceholder? placeholder})
const

Properties

box CampaignCanvasBox
finalinherited
fit BoxFit
final
hashCode int
The hash code for this object.
no setterinherited
placeholder ImagePlaceholder?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
url String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited