CampaignCanvasImageBackground class final

Inheritance

Constructors

CampaignCanvasImageBackground(String imageUrl, {double positionX = .5, double positionY = .5, double scale = 1})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
imageUrl String
final
positionX double
final
positionY double
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
scale double
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited