CampaignCanvasParser class final
Decodes the Canvas wire format without depending on a campaign surface.
A host may provide allowedWidgetTypes when a surface supports only a
subset of the Canvas palette. Unknown and disallowed widgets are skipped.
Constructors
- CampaignCanvasParser({DesignTokenCatalog designTokens = DesignTokenCatalog.empty})
-
const
Properties
- designTokens → DesignTokenCatalog
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
parse(
Map< String, dynamic> json, {Set<String> allowedWidgetTypes = supportedCampaignCanvasWidgetTypes}) → CampaignCanvas -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited