getInlineCampaign method
Gets the active inline campaign for a given placement key, if any.
Implementation
InAppPayload? getInlineCampaign(String placementKey) =>
inlineController.getCampaign(placementKey);
Gets the active inline campaign for a given placement key, if any.
InAppPayload? getInlineCampaign(String placementKey) =>
inlineController.getCampaign(placementKey);