onHostUnmounted method
void
onHostUnmounted()
Called by DigiaHost when it is removed from the widget tree.
Implementation
void onHostUnmounted() {
_hostMounted = false;
_logIfVerbose('DigiaHost unmounted.');
}
Called by DigiaHost when it is removed from the widget tree.
void onHostUnmounted() {
_hostMounted = false;
_logIfVerbose('DigiaHost unmounted.');
}