getInlineConfig method
The render config for slotKey, or null when no inline campaign is active.
Implementation
CampaignConfigModel? getInlineConfig(String slotKey) => _slotConfigs[slotKey];
The render config for slotKey, or null when no inline campaign is active.
CampaignConfigModel? getInlineConfig(String slotKey) => _slotConfigs[slotKey];