show method
Called by DigiaInstance when a new experience is ready to render. Notifies DigiaHost to rebuild and display the overlay.
Implementation
void show(InAppPayload payload) {
_activePayload = payload;
notifyListeners();
}
Called by DigiaInstance when a new experience is ready to render. Notifies DigiaHost to rebuild and display the overlay.
void show(InAppPayload payload) {
_activePayload = payload;
notifyListeners();
}