GuideDismissed class

Guide abandoned (rolls up step-level dismiss).

Inheritance

Constructors

GuideDismissed({int? abandonedAtItem, int? itemTotal, int? dwellMs})
const

Properties

abandonedAtItem int?
final
dwellMs int?
final
eventName String
no setteroverride
hashCode int
The hash code for this object.
no setterinherited
itemTotal int?
final
properties Map<String, Object?>
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited