GuideStepClicked class

Inheritance

Constructors

GuideStepClicked({required int itemIndex, String? elementId, String? ctaLabel, String? actionType, String? actionUrl})
const

Properties

actionType String?
final
actionUrl String?
final
ctaLabel String?
final
elementId String?
final
eventName String
no setteroverride
hashCode int
The hash code for this object.
no setterinherited
itemIndex int
final
properties Map<String, Object?>
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited