NudgeViewed class
- Inheritance
-
- Object
- EngageAnalyticsEvent
- NudgeEvent
- NudgeViewed
Constructors
- NudgeViewed({required String displayStyle, TriggerContext? trigger, String? screenName})
-
const
Properties
- displayStyle → String
-
final
- eventName → String
-
no setteroverride
- hashCode → int
-
The hash code for this object.
no setterinherited
-
properties
→ Map<
String, Object?> -
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- screenName → String?
-
final
- trigger → TriggerContext?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited