PipEvent class sealed
Picture-in-picture analytics.
PiP deliberately uses the existing experience/step event names. Collapsed SDK chrome is experience-level; authored buttons inside the expanded nudge tree are step-level CTA clicks.
- Inheritance
-
- Object
- EngageAnalyticsEvent
- PipEvent
- Implementers
Properties
- eventName → String
-
no setterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
-
properties
→ Map<
String, Object?> -
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited