PipStepClicked class

Authored CTA button taps inside the expanded PiP content.

Inheritance

Constructors

PipStepClicked({required String elementId, required String ctaLabel, required String actionType, required String ctaRole, String? actionUrl, int? timeToActionMs})
const

Properties

actionType String
final
actionUrl String?
final
ctaLabel String
final
ctaRole String
final
elementId String
final
eventName String
no setteroverride
hashCode int
The hash code for this object.
no setterinherited
properties Map<String, Object?>
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
timeToActionMs int?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited