TriggerContext class

Trigger attribution shared by every campaign's "Viewed" event.

Mirrors Android's TriggerContext.

Constructors

TriggerContext(TriggerType type, {String? event})
const

Properties

event String?
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type TriggerType
final

Methods

asProperties() Map<String, Object?>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited