FrequencyEvalResult class

The result of evaluating a policy against a state. Mirrors Android's FrequencyEvalResult.

Constructors

FrequencyEvalResult(bool allow, [FrequencySkipReason? reason])
const

Properties

allow bool
final
hashCode int
The hash code for this object.
no setterinherited
reason FrequencySkipReason?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

allowed → const FrequencyEvalResult