GuideConfig class sealed

Implementers

Properties

anchorKeys List<String>
no setter
firstAnchorKey String
no setter
hashCode int
The hash code for this object.
no setterinherited
outsideTapBehavior String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stepCount int
no setter
templateId String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

fromCampaignJson(Map<String, dynamic> json) GuideConfig?
Parses a guide from a campaign's JSON, mirroring RN's _parseTemplateConfig (flat templateConfig with templateType tooltip/spotlight).