SpotlightStep class
Constructors
-
SpotlightStep({required String anchorKey, required int? delayInMs, required String title, required String body, required String calloutPosition, required double calloutGap, required Color overlayColor, required double overlayOpacity, required String highlightShape, required double highlightCornerRadius, required double highlightPadding, required Color highlightGlowColor, required double highlightGlowWidth, required Color calloutBackgroundColor, required double calloutCornerRadius, required double calloutMaxWidth, required double calloutPadding, required bool calloutShadow, required Color calloutBorderColor, required double calloutBorderWidth, required bool showArrow, required Color? arrowColor, required Color? arrowBorderColor, required double arrowSize, required Color titleColor, required double titleSize, required FontWeight titleWeight, required Color bodyColor, required double bodySize, required Color buttonPrimaryBackgroundColor, required Color buttonPrimaryTextColor, required Color buttonGhostTextColor, required List<
GuideAction> actions}) -
const
Properties
-
actions
→ List<
GuideAction> -
final
- anchorKey → String
-
final
- arrowBorderColor → Color?
-
final
- arrowColor → Color?
-
final
- arrowSize → double
-
final
- body → String
-
final
- bodyColor → Color
-
final
- bodySize → double
-
final
-
final
-
final
-
final
- calloutBackgroundColor → Color
-
final
- calloutBorderColor → Color
-
final
- calloutBorderWidth → double
-
final
- calloutCornerRadius → double
-
final
- calloutGap → double
-
final
- calloutMaxWidth → double
-
final
- calloutPadding → double
-
final
- calloutPosition → String
-
final
- calloutShadow → bool
-
final
- delayInMs → int?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- highlightCornerRadius → double
-
final
- highlightGlowColor → Color
-
final
- highlightGlowWidth → double
-
final
- highlightPadding → double
-
final
- highlightShape → String
-
final
- overlayColor → Color
-
final
- overlayOpacity → double
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- showArrow → bool
-
final
- title → String
-
final
- titleColor → Color
-
final
- titleSize → double
-
final
- titleWeight → FontWeight
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
fromJson(
Map< String, dynamic> json) → SpotlightStep?