ActiveGuideState class

The guide campaign currently routed for display. token is unique per showing so the renderer can key a fresh overlay session to it.

Constructors

ActiveGuideState({required CampaignModel campaign, required CEPTriggerPayload payload, required int token})

Properties

campaign CampaignModel
final
config GuideConfig
final
hashCode int
The hash code for this object.
no setterinherited
payload CEPTriggerPayload
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
token int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited