disableBarrierInteraction property
Whether scrim/barrier taps are inert (outsideTapBehavior == 'nothing').
When false, the engine advances or dismisses after the last step.
Implementation
final bool disableBarrierInteraction;
Whether scrim/barrier taps are inert (outsideTapBehavior == 'nothing').
When false, the engine advances or dismisses after the last step.
final bool disableBarrierInteraction;