NudgeCloseButtonConfig class

Constructors

NudgeCloseButtonConfig({double marginTop = 12, double marginRight = 12, Color backgroundColor = const Color(0x14000000), Color iconColor = const Color(0xFF66667A), double iconSize = 16})
const

Properties

backgroundColor Color
final
diameter double
no setter
hashCode int
The hash code for this object.
no setterinherited
iconColor Color
final
iconSize double
final
marginRight double
final
marginTop double
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
scaled(double factor) NudgeCloseButtonConfig
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited