NudgeCarousel class

Inheritance

Constructors

NudgeCarousel(NudgeBox box, {required List<String> images, required double height, required bool autoPlay, required int autoPlayInterval, required bool loop, required bool showIndicator})
const

Properties

autoPlay bool
final
autoPlayInterval int
final
box NudgeBox
finalinherited
hashCode int
The hash code for this object.
no setterinherited
height double
final
images List<String>
final
loop bool
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
showIndicator bool
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited