NudgeColumn class

Constructors

NudgeColumn({required CrossAxisAlignment crossAxisAlignment, required MainAxisAlignment mainAxisAlignment, required double spacing, required List<NudgeNode> children})
const

Properties

children List<NudgeNode>
final
crossAxisAlignment CrossAxisAlignment
final
hashCode int
The hash code for this object.
no setterinherited
mainAxisAlignment MainAxisAlignment
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
spacing double
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited