NudgeDivider class

Inheritance

Constructors

NudgeDivider(NudgeBox box, {required double thickness, required double indent, required double endIndent, required Color color})
const

Properties

box NudgeBox
finalinherited
color Color
final
endIndent double
final
hashCode int
The hash code for this object.
no setterinherited
indent double
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
thickness double
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited