NudgeImage class

Inheritance

Constructors

NudgeImage(NudgeBox box, {required String url, required BoxFit fit, required double aspectRatio})
const

Properties

aspectRatio double
Width-to-height ratio; 0 = off (use the box's fixed height / natural size).
final
box NudgeBox
finalinherited
fit BoxFit
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
url String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited