NudgeVideo class

Inheritance

Constructors

NudgeVideo(NudgeBox box, {required String url, required double height, required bool autoplay, required bool loop, required bool showControls, required bool muted})
const

Properties

autoplay bool
final
box NudgeBox
finalinherited
hashCode int
The hash code for this object.
no setterinherited
height double
final
loop bool
final
muted bool
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
showControls bool
final
url String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited