hasFixedHeight property
bool
get
hasFixedHeight
Whether the author pinned an explicit height rather than a ratio.
Implementation
bool get hasFixedHeight => heightDp > 0;
Whether the author pinned an explicit height rather than a ratio.
bool get hasFixedHeight => heightDp > 0;