PipEntryAnimation class
How the collapsed window arrives on screen.
Constructors
- PipEntryAnimation({PipEntryAnimationType type = PipEntryAnimationType.appear, PipFlyDirection from = PipFlyDirection.right, Duration duration = const Duration(milliseconds: 300)})
-
const
-
PipEntryAnimation.fromJson(Map<
String, dynamic> ? json) -
factory
Properties
- duration → Duration
-
final
- from → PipFlyDirection
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- type → PipEntryAnimationType
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited