PipExitAnimation class

How the collapsed window leaves. none tears down instantly.

Constructors

PipExitAnimation({PipExitAnimationType type = PipExitAnimationType.fadeOut, PipFlyDirection to = PipFlyDirection.right, Duration duration = const Duration(milliseconds: 200)})
const
PipExitAnimation.fromJson(Map<String, dynamic>? json)
factory

Properties

duration Duration
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
to PipFlyDirection
final
type PipExitAnimationType
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited