campaignKey property
The coupling key that links this CEP campaign to a Digia campaign. Core uses this to look up the matching WidgetConfig in CampaignStore.
Implementation
final String campaignKey;
The coupling key that links this CEP campaign to a Digia campaign. Core uses this to look up the matching WidgetConfig in CampaignStore.
final String campaignKey;