DiagnosticReport class

Plugin health report returned by DigiaCEPPlugin.healthCheck.

Constructors

DiagnosticReport({required bool isHealthy, String? issue, String? resolution, Map<String, dynamic> metadata = const <String, dynamic>{}})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
isHealthy bool
final
issue String?
final
metadata Map<String, dynamic>
final
resolution String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited