developerConfig property
Optional developer configuration for proxies, inspectors, and custom backend URLs. Defaults to DeveloperConfig with production base URL when omitted.
Implementation
final DeveloperConfig? developerConfig;
Optional developer configuration for proxies, inspectors, and custom backend URLs. Defaults to DeveloperConfig with production base URL when omitted.
final DeveloperConfig? developerConfig;