themeMode property
Theme selection for canvas design tokens. Optional and additive so existing integrations continue to follow the device automatically.
Implementation
final DigiaThemeMode themeMode;
Theme selection for canvas design tokens. Optional and additive so existing integrations continue to follow the device automatically.
final DigiaThemeMode themeMode;