elementId property

String? elementId
final

Identifier of the element clicked, if defined in the campaign artifact. Null if the entire experience surface was the tap target.

Implementation

final String? elementId;