content property

Map<String, dynamic> content
final

Raw content map from the CEP campaign. Digia's rendering engine reads this to construct the experience. Schema is defined by the Digia dashboard campaign format.

Implementation

final Map<String, dynamic> content;