onItemTap property
Invoked when a slide is tapped, carrying the slide with its {{ }}
placeholders already resolved against the active VariableScope.
Implementation
final void Function(CarouselItem item)? onItemTap;
Invoked when a slide is tapped, carrying the slide with its {{ }}
placeholders already resolved against the active VariableScope.
final void Function(CarouselItem item)? onItemTap;