DUIAppState class

Global state manager that holds multiple reactive values

Constructors

DUIAppState()
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value Map<String, ReactiveValue<Object?>>
no setter

Methods

dispose() → void
Dispose all registered values
get<T>(String key) → ReactiveValue<T>
Get a reactive value by key
getValue<T>(String key) → T
Get the current value by key
init(List values) Future<void>
Initialize the global state with SharedPreferences and state descriptors
listen<T>(String key, void onData(T)) StreamSubscription<T>
Listen to changes of a value
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
update<T>(String key, T newValue) bool
Update a value by key

Operators

operator ==(Object other) bool
The equality operator.
inherited