host property

DigiaUIHost? host
final

Host configuration for custom deployment environments.

Allows overriding the default hosting configuration to connect to custom backend deployments or use different resource serving strategies.

Implementation

final DigiaUIHost? host;