inspector property

DigiaInspector? inspector
final

Inspector instance for capturing debug information and events.

Custom inspectors can be provided to integrate with existing logging infrastructure or to capture specific types of debug information. The inspector receives events from throughout the Digia UI system.

Implementation

final DigiaInspector? inspector;