Message class

Represents an event that can be dispatched through the message bus

Constructors

Message({required String name, Object? payload, BuildContext? context})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
name String
final
payload Object?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

getMountedContext() BuildContext?
WARNING: This context comes from deep within the SDK and should be used with extreme caution. Misusing this context can lead to multiple problems including:
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited