MessageBus.customController constructor

MessageBus.customController(
  1. StreamController controller
)

Instead of using the default StreamController you can use this constructor to pass your own controller.

This allows for custom message handling implementations if needed.

Implementation

MessageBus.customController(StreamController controller)
    : _streamController = controller;