RenderPayload class

Constructors

RenderPayload({required BuildContext buildContext, required ScopeContext scopeContext, List<String> widgetHierarchy = const [], String? currentEntityId})

Properties

buildContext BuildContext
final
currentEntityId String?
final
hashCode int
The hash code for this object.
no setterinherited
observabilityContext → ObservabilityContext?
Gets the current ObservabilityContext from payload fields
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
scopeContext → ScopeContext
final
widgetHierarchy List<String>
final

Methods

copyWith({BuildContext? buildContext, ScopeContext? scopeContext, List<String>? widgetHierarchy, String? currentEntityId}) RenderPayload
copyWithChainedContext(ScopeContext scopeContext, {BuildContext? buildContext}) RenderPayload
eval<T extends Object>(Object? expression, {ScopeContext? scopeContext, T? decoder(Object?)?}) → T?
evalColor(Object? expression, {ScopeContext? scopeContext, String? decoder(Object?)?}) Color?
evalColorExpr(ExprOr<String>? expression, {ScopeContext? scopeContext, String? decoder(Object?)?}) Color?
evalExpr<T extends Object>(ExprOr<T>? expr, {T? decoder(Object)?}) → T?
executeAction(ActionFlow? actionFlow, {ScopeContext? scopeContext, String? triggerType}) Future<Object?>?
Executes an action flow with optional trigger context
forComponent({required String componentId}) RenderPayload
Creates a new RenderPayload for a component, replacing the entity ID and preserving the page hierarchy as a prefix
getApiModel(String id) → APIModel?
getColor(String key) Color?
getFontFactory() DUIFontFactory?
getIcon(Map<String, Object?>? map) IconData?
getTextStyle(JsonLike? json, [TextStyle? fallback = defaultTextStyle]) TextStyle?
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
withExtendedHierarchy(String widgetName) RenderPayload
Creates a new RenderPayload with an extended widget hierarchy

Operators

operator ==(Object other) bool
The equality operator.
inherited