forComponent method
Creates a new RenderPayload for a component, replacing the entity ID and preserving the page hierarchy as a prefix
Implementation
RenderPayload forComponent({required String componentId}) {
// When entering a component from a page, preserve the page hierarchy
// by adding the component ID to the hierarchy
return copyWith(
widgetHierarchy: [...widgetHierarchy, componentId],
currentEntityId: componentId,
);
}