To class abstract

Constructors

To()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

alignment(dynamic value) Alignment?
axis(dynamic value) Axis?
blurStyle(dynamic value) BlurStyle?
border(({Color? color, StrokeAlign? strokeAlign, String? style, double? width})? border) Border?
borderPattern(dynamic value) → BorderPattern?
borderRadius(dynamic value, {BorderRadius? or = BorderRadius.zero}) BorderRadius
borderSide(dynamic value, {required Color? evalColor(Object?)}) BorderSide?
borderWithPattern(dynamic value, {required Color? evalColor(Object? expr)}) → BorderWithPattern?
boxFit(dynamic value) BoxFit
buttonShape(dynamic value, Color? toColor(String)) OutlinedBorder?
clip(dynamic value) Clip?
crossAxisAlignment(dynamic value) CrossAxisAlignment?
curve(dynamic curveString) Curve?
dashPattern(dynamic jsonDashPattern) List<double>?
edgeInsets(dynamic value, {EdgeInsets or = EdgeInsets.zero}) EdgeInsets
Converts a dynamic value to EdgeInsets.
expandablePanelBodyAlignment(dynamic value) → ExpandablePanelBodyAlignment?
expandablePanelHeaderAlignment(dynamic value) → ExpandablePanelHeaderAlignment?
expandablePanelIconPlacement(dynamic value) → ExpandablePanelIconPlacement?
fontStyle(dynamic value) FontStyle
fontWeight(dynamic value) FontWeight
gradient(Map<String, Object?>? data, {required Color? evalColor(Object?)}) Gradient?
inputFormatters(dynamic value) List<TextInputFormatter>?
mainAxisAlignment(dynamic value) MainAxisAlignment?
mainAxisSize(dynamic value) MainAxisSize?
scrollPhysics(dynamic physics) ScrollPhysics?
stackChildAlignment(String? fit) AlignmentDirectional
stackFit(dynamic value) StackFit
strokeAlign(dynamic string) → StrokeAlign?
strokeCap(dynamic value) StrokeCap?
tabBarIndicatorSize(dynamic value) TabBarIndicatorSize?
textAlign(dynamic value) TextAlign
textCapitalization(dynamic value) TextCapitalization
textDecoration(dynamic value) TextDecoration?
textDecorationStyle(dynamic value) TextDecorationStyle?
textOverflow(dynamic value) TextOverflow
toKeyBoardType(dynamic value) TextInputType?
toLineStyle(String? style) → DividerLineStyle?
toRadius(dynamic value) Radius
toTextInputAction(dynamic value) TextInputAction?
uriLaunchMode(dynamic value) → LaunchMode
verticalDirection(String? value) VerticalDirection?
wrapAlignment(dynamic value) WrapAlignment?
wrapCrossAlignment(String? value) WrapCrossAlignment?