VWImage class

Inheritance

Constructors

VWImage({required Props props, required CommonProps? commonProps, Props? parentProps, required VirtualWidget? parent, String? refName})
VWImage.fromValues({required String? imageSrc, String? imageFit})

Properties

commonProps ↔ CommonProps?
getter/setter pairinherited
hashCode int
The hash code for this object.
no setterinherited
parent → VirtualWidget?
no setterinherited
parentProps ↔ Props?
getter/setter pairinherited
props ↔ Props
getter/setter pairinherited
refName String?
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

empty() Widget
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
render(RenderPayload payload) Widget
toString() String
A string representation of this object.
inherited
toWidget(RenderPayload payload) Widget
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited