VirtualLeafStatelessWidget<T> class abstract

Implementers

Constructors

VirtualLeafStatelessWidget({required T props, required CommonProps? commonProps, required VirtualWidget? parent, required String? refName, Props? parentProps})

Properties

commonProps ↔ CommonProps?
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
parent → VirtualWidget?
no setterinherited
parentProps ↔ Props?
getter/setter pairinherited
props ↔ T
getter/setter pair
refName String?
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

empty() Widget
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
render(RenderPayload payload) Widget
inherited
toString() String
A string representation of this object.
inherited
toWidget(RenderPayload payload) Widget

Operators

operator ==(Object other) bool
The equality operator.
inherited