InlineBannerConfig class

Image-only Banner configuration rendered inside a DigiaSlot.

Constructors

InlineBannerConfig({required String slotKey, required InlineBannerImageConfig image, InlineBannerMargin margin = const InlineBannerMargin(), Map<String, dynamic> onClick = const {'steps' : <dynamic>[]}})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
image InlineBannerImageConfig
final
margin InlineBannerMargin
final
onClick Map<String, dynamic>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
slotKey String
final

Methods

firstActionMetadata(VariableScope scope) InlineBannerActionMetadata
hasActionsFor(VariableScope scope) bool
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
resolvedActions(VariableScope scope) List<EngageAction>
resolvedOnClick(VariableScope scope) Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

fromJson(Map<String, dynamic> json) InlineBannerConfig?