InlineBannerImageConfig class
Constructors
- InlineBannerImageConfig({required String url, ImagePlaceholder? placeholder, BoxFit boxFit = BoxFit.cover, double aspectRatio = 16 / 9, double height = 200, double cornerRadius = 12})
-
const
Properties
- aspectRatio → double
-
final
- boxFit → BoxFit
-
final
- cornerRadius → double
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- height → double
-
final
- placeholder → ImagePlaceholder?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- url → String
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
fromJson(
Map< String, dynamic> ? json) → InlineBannerImageConfig?