InlineTimerConfig class final
Parsed stateful inline timer before trigger variables are known.
Constructors
-
InlineTimerConfig({required String slotKey, required double designWidth, required double cornerRadius, required InlineCanvasMargin margin, required InlineTimerInstant? startsAt, required InlineTimerInstant deadline, required int? urgentBelowSeconds, required Map<
InlineTimerState, InlineTimerRule> rules, required ServerTimeClock clock}) -
const
Properties
- clock → ServerTimeClock
-
final
- cornerRadius → double
-
final
- deadline → InlineTimerInstant
-
final
- designWidth → double
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- margin → InlineCanvasMargin
-
final
-
rules
→ Map<
InlineTimerState, InlineTimerRule> -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- slotKey → String
-
final
- startsAt → InlineTimerInstant?
-
final
- urgentBelowSeconds → int?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
resolve(
VariableScope scope, {Map< String, dynamic> ? runtimeVariables}) → ResolvedInlineTimerConfig? -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
fromJson(
Map< String, dynamic> json, {required DesignTokenCatalog designTokens, required ServerTimeClock? serverClock}) → InlineTimerConfig?