api/internal/campaign/inline_carousel_config library

Classes

CarouselIndicatorConfig
Page-indicator styling for an inline carousel.
CarouselItem
A single image slide in an inline carousel campaign.
InlineCarouselConfig
Configuration for an inline carousel campaign, surfaced through DigiaSlot at the placement identified by slotKey.