CountdownDeadline class
A variable-capable ISO 8601 deadline expression.
Values without a zone use India's fixed UTC+05:30 offset. Explicit Z,
+HH, +HHMM, and +HH:MM offsets take precedence.
Constructors
- CountdownDeadline(String expression)
-
const
Properties
- expression → String
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
resolve(
VariableScope variables) → DateTime? -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- defaultOffset → const Duration