ResolvedInlineCountdownConfig class
Constructors
-
ResolvedInlineCountdownConfig({required String slotKey, required CountdownHeaderContent activeContent, required DateTime deadline, required CountdownExpiredContent expiredContent, required List<
EngageAction> onClick, required List<EngageAction> expiredOnClick}) -
const
Properties
- activeContent → CountdownHeaderContent
-
final
- deadline → DateTime
-
final
- expiredContent → CountdownExpiredContent
-
final
-
expiredOnClick
→ List<
EngageAction> -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
onClick
→ List<
EngageAction> -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- slotKey → String
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited