CampaignCanvasBox class final
Visual decoration inside a Canvas child's authoritative rectangle.
Canvas intentionally has no classic layout fields such as outer margin, fixed width/height, fill width, or self alignment. The child rectangle owns geometry; this model only decorates its contents.
Constructors
- CampaignCanvasBox({CampaignColor? background, EdgeInsets padding = EdgeInsets.zero, BorderRadius borderRadius = BorderRadius.zero, CampaignColor? borderColor, double borderWidth = 0, CampaignCanvasShadow? shadow})
-
const
Properties
- background → CampaignColor?
-
final
- borderColor → CampaignColor?
-
final
- borderRadius → BorderRadius
-
final
- borderWidth → double
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- padding → EdgeInsets
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- shadow → CampaignCanvasShadow?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- none → const CampaignCanvasBox