onEvent property
Set by DigiaInstance at init time. DigiaHost calls this when a user interaction event occurs. DigiaInstance handles the event and forwards it to the active plugin.
Implementation
void Function(DigiaExperienceEvent, InAppPayload)? onEvent;