show method
Called by DigiaInstance when a new modal experience is ready to render. Notifies DigiaHost to present the overlay.
Implementation
void show(CEPTriggerPayload payload) {
_activePayload = payload;
notifyListeners();
}
Called by DigiaInstance when a new modal experience is ready to render. Notifies DigiaHost to present the overlay.
void show(CEPTriggerPayload payload) {
_activePayload = payload;
notifyListeners();
}