CarouselStepViewed class
- Inheritance
-
- Object
- EngageAnalyticsEvent
- CarouselEvent
- CarouselStepViewed
Constructors
- CarouselStepViewed({required int itemIndex, int? itemTotal, String? itemId, bool? auto})
-
const
Properties
- auto → bool?
-
True when the carousel auto-advanced to this item; false on a manual swipe.
final
- eventName → String
-
no setteroverride
- hashCode → int
-
The hash code for this object.
no setterinherited
- itemId → String?
-
final
- itemIndex → int
-
final
- itemTotal → int?
-
final
-
properties
→ Map<
String, Object?> -
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited