SurveyQuestionViewed class
- Inheritance
-
- Object
- EngageAnalyticsEvent
- SurveyEvent
- SurveyQuestionViewed
Constructors
Properties
- blockId → String?
-
final
- blockType → String?
-
final
- eventName → String
-
no setteroverride
- hashCode → int
-
The hash code for this object.
no setterinherited
- isRequired → bool?
-
final
- itemIndex → int?
-
final
- itemTotal → int?
-
final
-
properties
→ Map<
String, Object?> -
no setteroverride
- questionId → String
-
final
- questionTitle → String?
-
final
- questionType → String?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited