GuideAction class
A guide button whose wire action has already been normalized.
Legacy fields are consumed only by fromJson. Callers see one executable action list and the analytics classification derived from that list.
Constructors
-
GuideAction({required String label, required GuideActionStyle style, required List<
EngageAction> actions, required String analyticsType, required Color? backgroundColor, required Color? textColor, required double fontSize, required FontWeight fontWeight, required double cornerRadius, required EdgeInsets padding, required EdgeInsets? margin}) -
const
Properties
-
actions
→ List<
EngageAction> -
final
- analyticsType → String
-
final
- backgroundColor → Color?
-
final
- cornerRadius → double
-
final
- fontSize → double
-
final
- fontWeight → FontWeight
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- label → String
-
final
- margin → EdgeInsets?
-
final
- padding → EdgeInsets
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- style → GuideActionStyle
-
final
- textColor → Color?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
fromJson(
Map< String, dynamic> json) → GuideAction