GuideAction class
A guide button, mirroring RN's Action discriminated union.
Constructors
-
GuideAction({required GuideActionType type, required String label, required GuideActionStyle style, String? scope, String? url, String? fallbackUrl, String? presentation, String? eventName, Map<
String, dynamic> ? properties}) -
const
Properties
- eventName → String?
-
final
- fallbackUrl → String?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- label → String
-
final
- presentation → String?
-
final
-
properties
→ Map<
String, dynamic> ? -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- scope → String?
-
final
- style → GuideActionStyle
-
final
- type → GuideActionType
-
final
- url → String?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
fromJson(
Map< String, dynamic> json) → GuideAction