SpotlightGuideConfig class
- Inheritance
-
- Object
- GuideConfig
- SpotlightGuideConfig
Constructors
-
SpotlightGuideConfig({required List<
SpotlightStep> steps, String? templateId, String outsideTapBehavior = 'next'}) -
const
Properties
-
anchorKeys
→ List<
String> -
no setteroverride
- firstAnchorKey → String
-
no setteroverride
- hashCode → int
-
The hash code for this object.
no setterinherited
- outsideTapBehavior → String
-
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- stepCount → int
-
no setteroverride
-
steps
→ List<
SpotlightStep> -
final
- templateId → String?
-
finalinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited