TooltipStep class
Constructors
-
TooltipStep({required String anchorKey, required int? delayInMs, required String title, required String body, required String placement, required Color backgroundColor, required Color borderColor, required double borderWidth, required double cornerRadius, required bool shadow, required double maxWidth, required double padding, required bool showArrow, required Color? arrowColor, required Color? arrowBorderColor, required double arrowSize, required Color titleColor, required double titleSize, required FontWeight titleWeight, required Color bodyColor, required double bodySize, required Color buttonPrimaryBackgroundColor, required Color buttonPrimaryTextColor, required Color buttonGhostTextColor, required List<
GuideAction> actions}) -
const
Properties
-
actions
→ List<
GuideAction> -
final
- anchorKey → String
-
final
- arrowBorderColor → Color?
-
final
- arrowColor → Color?
-
final
- arrowSize → double
-
final
- backgroundColor → Color
-
final
- body → String
-
final
- bodyColor → Color
-
final
- bodySize → double
-
final
- borderColor → Color
-
final
- borderWidth → double
-
final
-
final
-
final
-
final
- cornerRadius → double
-
final
- delayInMs → int?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- maxWidth → double
-
final
- padding → double
-
final
- placement → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- shadow → bool
-
final
- showArrow → bool
-
final
- title → String
-
final
- titleColor → Color
-
final
- titleSize → double
-
final
- titleWeight → FontWeight
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
fromJson(
Map< String, dynamic> json) → TooltipStep?