NudgeSpanStyle class
Per-run style overrides. Every field is null/false when the run inherits
the Text widget's base style for that property (the dashboard's span.style).
Constructors
- NudgeSpanStyle({FontWeight? weight, double? fontSize, Color? color, Color? highlightColor, bool italic = false, TextDecoration? decoration, Color? decorationColor, double? decorationThickness})
-
const
Properties
- color → Color?
-
final
- decoration → TextDecoration?
-
Text decoration (single, not combinable): underline, line-through, or none.
final
- decorationColor → Color?
-
Decoration line colour;
null= same as the text colour.final - decorationThickness → double?
-
Decoration line thickness as a multiplier of the font default;
null= default.final - fontSize → double?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- highlightColor → Color?
-
Highlight/background colour behind the run;
null= none.final - italic → bool
-
Italic when true.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- weight → FontWeight?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited