NudgeText class

Inheritance

Constructors

NudgeText(NudgeBox box, {required String text, required double fontSize, required FontWeight weight, required Color color, required TextAlign align})
const

Properties

align TextAlign
final
box NudgeBox
finalinherited
color Color
final
fontSize double
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
text String
final
weight FontWeight
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited