spans property
Optional rich overlay: styled runs drawn on top of the base style above. Empty = render the plain text with the base style, exactly as before.
Implementation
final List<NudgeTextSpan> spans;
Optional rich overlay: styled runs drawn on top of the base style above. Empty = render the plain text with the base style, exactly as before.
final List<NudgeTextSpan> spans;