PipConfig class
A fully parsed PiP campaign.
Constructors
- PipConfig({required PipMedia media, required PipExpanded expanded, PipCollapsed collapsed = const PipCollapsed(), PipControls controls = const PipControls(), PipBehavior behavior = const PipBehavior()})
-
const
Properties
- behavior → PipBehavior
-
final
- collapsed → PipCollapsed
-
final
- controls → PipControls
-
final
- expanded → PipExpanded
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- media → PipMedia
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
fromJson(
Map< String, dynamic> ? json, {DesignTokenCatalog designTokens = DesignTokenCatalog.empty}) → PipConfig? -
Parses
templateConfig. Returns null when the campaign could not render meaningfully — no media, or no expanded canvas to open.