ExperienceClicked class
The user interacted with an actionable element. Map to: CleverTap syncTemplate (clicked), MoEngage trackClick
- Inheritance
-
- Object
- DigiaExperienceEvent
- ExperienceClicked
Constructors
- ExperienceClicked({String? elementId})
-
const
Properties
- elementId → String?
-
Identifier of the element clicked, if defined in the campaign artifact.
Null if the entire experience surface was the tap target.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited