elementId property
Identifier of the element clicked, if defined in the campaign artifact. Null if the entire experience surface was the tap target.
Implementation
final String? elementId;
Identifier of the element clicked, if defined in the campaign artifact. Null if the entire experience surface was the tap target.
final String? elementId;