ActionFlow class
Constructors
-
ActionFlow({required List<
Action> actions, bool inkwell = true, List<JsonLike> ? analyticsData}) - ActionFlow.empty()
-
factory
Properties
-
actions
→ List<
Action> -
final
-
analyticsData
→ List<
JsonLike> ? -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- inkwell → bool
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
fromJson(
Object? json) → ActionFlow?