DUIAnalytics class abstract
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
onDataSourceError(
String dataSourceType, String source, DataSourceErrorInfo errorInfo) → void -
onDataSourceSuccess(
String dataSourceType, String source, dynamic metaData, dynamic perfData) → void -
onEvent(
List< AnalyticEvent> events) → void -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited