DashboardHost class
Host configuration for Digia Dashboard deployment.
DashboardHost represents the standard Digia Studio dashboard hosting environment. This is the most common deployment scenario where the application connects to the official Digia Studio backend services.
Example usage:
const host = DashboardHost(
resourceProxyUrl: 'https://cdn.example.com', // Optional
);
- Inheritance
-
- Object
- DigiaUIHost
- DashboardHost
Constructors
- DashboardHost({String? resourceProxyUrl})
-
Creates a new DashboardHost configuration.
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- resourceProxyUrl → String?
-
Optional URL for proxying resource requests (images, fonts, etc.)
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited