MessageBus class
Constructors
- MessageBus()
- Creates a MessageBus for handling communication between the DUI SDK and native code.
- MessageBus.customController(StreamController controller)
- Instead of using the default StreamController you can use this constructor to pass your own controller.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- streamController → StreamController
-
Controller for the message bus stream.
no setter
Methods
-
dispose(
) → void - Closes the message bus and cleans up resources. This should only be called when the SDK is being disposed.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
on(
[String? eventName]) → Stream< Message> - Listens for Messages with the specified name.
-
send(
Message event) → void - Sends an event through the message bus.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited