PreviewHost class
Host configuration for Digia Preview deployment.
PreviewHost represents the preview environment for Digia Studio. This is used for previewing changes before going live.
- Inheritance
-
- Object
- DigiaUIHost
- PreviewHost
Constructors
- PreviewHost({String? resourceProxyUrl})
-
Creates a new PreviewHost configuration.
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- resourceProxyUrl → String?
-
Optional URL for proxying resource requests (images, fonts, etc.)
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited