StateDescriptor<T> class
Describes how a state value should behave
Constructors
Properties
- description → String?
-
final
- deserialize → T Function(String)
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- initialValue → T
-
final
- key → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- serialize → String Function(T)
-
final
- shouldPersist → bool
-
final
- streamName → String
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited